@@ -200,6 +200,9 @@ meta_core_get (Display *xdisplay,
       case META_CORE_GET_FRAME_HEIGHT:
         *((gint*)answer) = window->frame->rect.height;
         break;
+      case META_CORE_GET_THEME_VARIANT:
+        *((char**)answer) = window->gtk_theme_variant;
+        break;
       case META_CORE_GET_SCREEN_WIDTH:
         *((gint*)answer) = window->screen->rect.width;
         break;
@@ -268,8 +271,7 @@ meta_core_user_lower_and_unfocus (Display *xdisplay,
 
   meta_window_lower (window);
 
-  if (meta_prefs_get_focus_mode () == META_FOCUS_MODE_CLICK &&
-      meta_prefs_get_raise_on_click ())
+  if (meta_prefs_get_raise_on_click ())
     {
       /* Move window to the back of the focusing workspace's MRU list.
        * Do extra sanity checks to avoid possible race conditions.
